package com.aspose.ocr.standalone;

import com.aspose.ocr.*;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.Writer;

public class OCRExample
{
    public void example1()
    {
        OcrEngine ocrEngine = new OcrEngine();
        ocrEngine.setConfig(new OCRConfig());
        String filename = "resources\\twoColumns.bmp";
        ocrEngine.getConfig().setProbabilityRow(1);
        String expectedResult = "^vve*+v   +<zJJ+t+r+>+t!\n" +
                "abcdefg    l\\ll\\[\\}\\(\\)([";
        String result = recognize(ocrEngine, filename);
        System.out.println(result);
    }

    private String recognize(OcrEngine ocrEngine, String pictureFile)
    {
        ocrEngine.setImage(ImageStream.fromFile(pictureFile));
        ZipFileStream zfs = new ZipFileStream("resources/Aspose.OCR.Resources.zip");
        ocrEngine.setResourceInternal(zfs);
        try
        {
            if (ocrEngine.process())
            {
                return ocrEngine.getText().toString();
            }
        }
        catch (java.lang.Exception ex)
        {
            ex.printStackTrace();
        }
        return null;
    }


    public void example2()
    {
        String imagePath = "resources/Sampleocr.bmp";
        String resourcesFilePath = "resources/";
        String MyDir = "C:\\";
        OcrEngine ocr = new OcrEngine();
        ocr.setImage(ImageStream.fromFile(imagePath));
        try
        {
            ocr.setResource(new FolderStream(resourcesFilePath));
            // Create a new file to write output
            Writer output = null;
            File file = new File(MyDir + "Output.txt");
            output = new java.io.BufferedWriter(new java.io.FileWriter(file));

            // Perform OCR and get extracted text
            if (ocr.process())
            {
                output.write("\ranswer -> " + ocr.getText());
            }

            output.close();
        } catch (Exception e)
        {
            e.printStackTrace();
        }
        System.out.println("Done");
    }

    public void example3()
    {
        final String pictureFile = "resources/Fox_CalibriBold32pt.bmp";

        OcrEngine _ocrEngine = new OcrEngine();
        _ocrEngine.getLanguages().addLanguage(Language.load("english"));
        _ocrEngine.clearNotifies();
        _ocrEngine.clearRecognitionBlocks();
        _ocrEngine.setImage(ImageStream.fromFile(pictureFile));

        ZipFileStream folderStream = new ZipFileStream("resources/Aspose.OCR.Resources.zip");
        _ocrEngine.setResourceInternal(folderStream);
        try
        {
            if (_ocrEngine.process())
            {
                String recognizedText = _ocrEngine.getText().toString();
                System.out.println(recognizedText);
            }
        } catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    public static void main(String[] args)
    {
        OCRExample example = new OCRExample();
         example.example1();
         example.example2();
         example.example3();
    }
}
